@@ -4,10 +4,12 @@
 pub use bytes::Bytes;
 
 pub mod args;
+pub mod blob;
 pub mod block;
 pub mod env;
 pub mod feature;
 pub mod i18n;
+pub mod model;
 pub mod output;
 pub mod prelude;
 pub mod skill;
